@@ -6,8 +6,8 @@ import os
 import re
 
 # import utils
-import datums
-import visuals
+from fuelcell import datums
+from fuelcell import visuals
 
-from datums import *
-from visuals import *
\ No newline at end of file
+from fuelcell.datums import *
+from fuelcell.visuals import *
\ No newline at end of file
