@@ -3,16 +3,16 @@ import pandas as pd
 import os
 import re
 
-import utils
+from fuelcell import utils
 
 dlm_default = utils.dlm_default
 col_default_labels = {'current':'i', 'potential':'v', 'time':'t', 'current_err':'i_sd', 'potential_err':'v_sd'}
-col_default_ids = {'current':1, 'potential':2, 'time':0, 'current_err':2, 'potential_err':3}
+col_default_ids = {'current':2, 'potential':1, 'time':0, 'current_err':2, 'potential_err':3}
 ref_electrodes = {'she':0, 'sce':0.241}
 
 
 def testfun():
-	print('thompson')
+	print('thomson (no p)')
 
 def ca_raw(filename=None, folder=None, pattern='', filetype='', delimiter=dlm_default):
 	"""
@@ -41,7 +41,7 @@ def ca_raw(filename=None, folder=None, pattern='', filetype='', delimiter=dlm_de
 	data = load_data(filename, folder, pattern, 'ca', filetype, delimiter)
 	return data
 
-def ca_process(data=None, current_column=1, potential_column=2, export_data=False, threshold=5, min_step_length=50, pts_to_average=300, pyramid=False, area=5, reference=None, **kwargs):
+def ca_process(data=None, current_column=2, potential_column=1, area=5, reference='she', export_data=False, save_dir='processed', threshold=5, min_step_length=50, pts_to_average=300, pyramid=False, **kwargs):
 	"""
 	Processes chronoamperometry data
 
@@ -79,7 +79,7 @@ def ca_process(data=None, current_column=1, potential_column=2, export_data=Fals
 		ca_processed = process_steps(df, potential_column, current_column, threshold, min_step_length, pts_to_average, pyramid, 'ca', area, reference)
 		newdata[k] = ca_processed
 		if export_data:
-			utils.save_data(ca_processed, k+'.csv', 'processed')
+			utils.save_data(ca_processed, k+'.csv', save_dir)
 	if len(newdata) == 1:
 		newdata = list(newdata.values())[0]
 	return newdata
@@ -100,8 +100,8 @@ def cp_raw(filename=None, folder=None, pattern='', filetype='', delimiter=dlm_de
 		If specified, only files matching this pattern in the specified folder are loaded. Ignored if filename is specified.
 	filetype : str
 		Any supported filetype. Only files of the specified file type will be loaded. Can be used in conjunction with pattern or expt_type.
-	delimiter : char (default = '\t')
-		Delimiting character if the file is a text file. Defaults to '\t' (tab-delimiting).
+	delimiter : char (default = '\\t')
+		Delimiting character if the file is a text file. Defaults to '\\t' (tab-delimiting).
 
 	Returns
 	________
@@ -111,7 +111,7 @@ def cp_raw(filename=None, folder=None, pattern='', filetype='', delimiter=dlm_de
 	data = load_data(filename, folder, pattern, 'cp', filetype, delimiter)
 	return data
 
-def cp_process(data=None, current_column=1, potential_column=2, export_data=False, threshold=5, min_step_length=25, pts_to_average=300, pyramid=True, area=5, reference=None, **kwargs):
+def cp_process(data=None, current_column=2, potential_column=1, area=5, reference='she', export_data=False, save_dir='processed', threshold=5, min_step_length=25, pts_to_average=300, pyramid=True, **kwargs):
 	"""
 	Processes chronopotentiometry data
 
@@ -149,7 +149,7 @@ def cp_process(data=None, current_column=1, potential_column=2, export_data=Fals
 		cp_processed = process_steps(df, current_column, potential_column, threshold, min_step_length, pts_to_average, pyramid, 'cp', area, reference)
 		newdata[k] = cp_processed
 		if export_data:
-			utils.save_data(cp_processed, k+'.csv', 'processed')
+			utils.save_data(cp_processed, k+'.csv', save_dir)
 	if len(newdata) == 1:
 		newdata = list(newdata.values())[0]
 	return newdata
@@ -181,7 +181,7 @@ def cv_raw(filename=None, folder=None, pattern='', filetype='', delimiter=dlm_de
 	data = load_data(filename, folder, pattern, 'cv', filetype, delimiter)
 	return data
 
-def cv_process(data=None, current_column=1, potential_column=0, export_data=False, area=5,  **kwargs):
+def cv_process(data=None, current_column=1, potential_column=0, area=5, reference='she', export_data=False, save_dir='processed', **kwargs):
 	"""
 	Processes cyclic voltammetry data
 
@@ -216,10 +216,11 @@ def cv_process(data=None, current_column=1, potential_column=0, export_data=Fals
 		current = find_col(df, 'current', current_column)
 		current = current / area
 		potential = find_col(df, 'potential', potential_column)
+		potenial = electrode_correct(potential, reference)
 		cv_processed = pd.DataFrame({'i':current,'v':potential})
 		newdata[k] = cv_processed
 		if export_data:
-			utils.save_data(cv_processed, k+'.csv', 'processed')
+			utils.save_data(cv_processed, k+'.csv', save_dir)
 	if len(newdata) == 1:
 		newdata = list(newdata.values())[0]
 	return newdata
